﻿# Why Refactor
The more lines found in a method, the harder it is to figure out what the method does. This is the main reason for this refactoring.

Besides eliminating rough edges in your code, extracting methods is also a step in many other refactoring approaches.

# Benefits
* More readable code! Be sure to give the new method a name that describes the method’s purpose: createOrder(), renderCustomerInfo(), etc.
* Less code duplication. Often the code that is found in a method can be reused in other places in your program. So you can replace duplicates with calls to your new method.
* Isolates independent parts of code, meaning that errors are less likely (such as if the wrong variable is modified).

# How to Refactor
1. Create a new method and name it in a way that makes its purpose self-evident.
2. Copy the relevant code fragment to your new method. Delete the fragment from its old location and put a call for the new method there instead.

# Sources
* https://sourcemaking.com/refactoring/extract-method
* Martin Fowler, Kent Beck: Refactoring, Improving the Design of Existing Code 

# Rider Support
* Shortcut: Ctrl + Alt + M
* Refactor -> Extract -> Extract method 
* See: https://www.jetbrains.com/help/rider/Refactorings__Extract_Method.html
