﻿# Why Refactor
The main reason for extracting variables is to make a complex expression more understandable, by dividing it into its intermediate parts.

These could be:
* Condition of the _if()_ operator or a part of the _?:_ operator in C-based languages
* A long arithmetic expression without intermediate results
* Long multipart lines

Extracting a variable may be the first step towards performing _Extract Method_ if you see that the extracted expression is used in other places in your code.

# Benefits
More readable code! Try to give the extracted variables good names that announce the variable’s purpose loud and clear. More readability, fewer long-winded comments. Go for names like customerTaxValue, cityUnemploymentRate, clientSalutationString, etc.

# Drawbacks
More variables are present in your code. But this is counterbalanced by the ease of reading your code.

# How to Refactor
1. Insert a new line before the relevant expression and declare a new variable there. Assign part of the complex expression to this variable.
2. Replace that part of the expression with the new variable.
3. Repeat the process for all complex parts of the expression.

# Sources
* https://sourcemaking.com/refactoring/extract-variable
* Martin Fowler, Kent Beck: Refactoring, Improving the Design of Existing Code 

# Rider Support
* Shortcut: Ctrl + Alt + V
* Refactor -> Introduce Variable... 
* See: https://www.jetbrains.com/help/rider/Refactorings__Introduce_Variable.html